# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'LicenseTierStateLicense',
    'GetLicenseTierStateLicenseResult',
]

@pulumi.output_type
class LicenseTierStateLicense(dict):
    def __init__(__self__, *,
                 name: builtins.str,
                 status: builtins.str):
        """
        :param builtins.str name: License name
                 - Choices: `ESSENTIAL`, `ADVANTAGE`, `PREMIER`, `DEVICEADMIN`, `VM`
        :param builtins.str status: License status
                 - Choices: `ENABLED`, `DISABLED`
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        License name
          - Choices: `ESSENTIAL`, `ADVANTAGE`, `PREMIER`, `DEVICEADMIN`, `VM`
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        License status
          - Choices: `ENABLED`, `DISABLED`
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class GetLicenseTierStateLicenseResult(dict):
    def __init__(__self__, *,
                 name: builtins.str,
                 status: builtins.str):
        """
        :param builtins.str name: License name
        :param builtins.str status: License status
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        License name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        License status
        """
        return pulumi.get(self, "status")


