# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetEgressMatrixCellDefaultResult',
    'AwaitableGetEgressMatrixCellDefaultResult',
    'get_egress_matrix_cell_default',
    'get_egress_matrix_cell_default_output',
]

@pulumi.output_type
class GetEgressMatrixCellDefaultResult:
    """
    A collection of values returned by getEgressMatrixCellDefault.
    """
    def __init__(__self__, default_rule=None, description=None, id=None, matrix_cell_status=None, sgacls=None):
        if default_rule and not isinstance(default_rule, str):
            raise TypeError("Expected argument 'default_rule' to be a str")
        pulumi.set(__self__, "default_rule", default_rule)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if matrix_cell_status and not isinstance(matrix_cell_status, str):
            raise TypeError("Expected argument 'matrix_cell_status' to be a str")
        pulumi.set(__self__, "matrix_cell_status", matrix_cell_status)
        if sgacls and not isinstance(sgacls, list):
            raise TypeError("Expected argument 'sgacls' to be a list")
        pulumi.set(__self__, "sgacls", sgacls)

    @property
    @pulumi.getter(name="defaultRule")
    def default_rule(self) -> builtins.str:
        """
        Can be used only if sgacls not specified. Final Catch All Rule
        """
        return pulumi.get(self, "default_rule")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The id of the object
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="matrixCellStatus")
    def matrix_cell_status(self) -> builtins.str:
        """
        Matrix Cell Status
        """
        return pulumi.get(self, "matrix_cell_status")

    @property
    @pulumi.getter
    def sgacls(self) -> Sequence[builtins.str]:
        """
        List of TrustSec Security Groups ACLs
        """
        return pulumi.get(self, "sgacls")


class AwaitableGetEgressMatrixCellDefaultResult(GetEgressMatrixCellDefaultResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEgressMatrixCellDefaultResult(
            default_rule=self.default_rule,
            description=self.description,
            id=self.id,
            matrix_cell_status=self.matrix_cell_status,
            sgacls=self.sgacls)


def get_egress_matrix_cell_default(id: Optional[builtins.str] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEgressMatrixCellDefaultResult:
    """
    This data source can read the TrustSec Egress Matrix Cell Default.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.trustsec.get_egress_matrix_cell_default(id="92c1a900-8c01-11e6-996c-525400b48521")
    ```


    :param builtins.str id: The id of the object
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ise:trustsec/getEgressMatrixCellDefault:getEgressMatrixCellDefault', __args__, opts=opts, typ=GetEgressMatrixCellDefaultResult).value

    return AwaitableGetEgressMatrixCellDefaultResult(
        default_rule=pulumi.get(__ret__, 'default_rule'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        matrix_cell_status=pulumi.get(__ret__, 'matrix_cell_status'),
        sgacls=pulumi.get(__ret__, 'sgacls'))
def get_egress_matrix_cell_default_output(id: Optional[pulumi.Input[builtins.str]] = None,
                                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEgressMatrixCellDefaultResult]:
    """
    This data source can read the TrustSec Egress Matrix Cell Default.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.trustsec.get_egress_matrix_cell_default(id="92c1a900-8c01-11e6-996c-525400b48521")
    ```


    :param builtins.str id: The id of the object
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ise:trustsec/getEgressMatrixCellDefault:getEgressMatrixCellDefault', __args__, opts=opts, typ=GetEgressMatrixCellDefaultResult)
    return __ret__.apply(lambda __response__: GetEgressMatrixCellDefaultResult(
        default_rule=pulumi.get(__response__, 'default_rule'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        matrix_cell_status=pulumi.get(__response__, 'matrix_cell_status'),
        sgacls=pulumi.get(__response__, 'sgacls')))
