# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from . import _utilities
import typing
# Export this package's modules as members:
from .provider import *

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_ise.config as __config
    config = __config
    import pulumi_ise.deviceadmin as __deviceadmin
    deviceadmin = __deviceadmin
    import pulumi_ise.identitymanagement as __identitymanagement
    identitymanagement = __identitymanagement
    import pulumi_ise.network as __network
    network = __network
    import pulumi_ise.networkaccess as __networkaccess
    networkaccess = __networkaccess
    import pulumi_ise.system as __system
    system = __system
    import pulumi_ise.trustsec as __trustsec
    trustsec = __trustsec
else:
    config = _utilities.lazy_import('pulumi_ise.config')
    deviceadmin = _utilities.lazy_import('pulumi_ise.deviceadmin')
    identitymanagement = _utilities.lazy_import('pulumi_ise.identitymanagement')
    network = _utilities.lazy_import('pulumi_ise.network')
    networkaccess = _utilities.lazy_import('pulumi_ise.networkaccess')
    system = _utilities.lazy_import('pulumi_ise.system')
    trustsec = _utilities.lazy_import('pulumi_ise.trustsec')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "ise",
  "mod": "deviceadmin/allowedProtocolsTacacs",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/allowedProtocolsTacacs:AllowedProtocolsTacacs": "AllowedProtocolsTacacs"
  }
 },
 {
  "pkg": "ise",
  "mod": "deviceadmin/authenticationRule",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/authenticationRule:AuthenticationRule": "AuthenticationRule"
  }
 },
 {
  "pkg": "ise",
  "mod": "deviceadmin/authenticationRuleUpdateRank",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/authenticationRuleUpdateRank:AuthenticationRuleUpdateRank": "AuthenticationRuleUpdateRank"
  }
 },
 {
  "pkg": "ise",
  "mod": "deviceadmin/authorizationExceptionRule",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/authorizationExceptionRule:AuthorizationExceptionRule": "AuthorizationExceptionRule"
  }
 },
 {
  "pkg": "ise",
  "mod": "deviceadmin/authorizationExceptionRuleUpdateRank",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/authorizationExceptionRuleUpdateRank:AuthorizationExceptionRuleUpdateRank": "AuthorizationExceptionRuleUpdateRank"
  }
 },
 {
  "pkg": "ise",
  "mod": "deviceadmin/authorizationGlobalExceptionRule",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/authorizationGlobalExceptionRule:AuthorizationGlobalExceptionRule": "AuthorizationGlobalExceptionRule"
  }
 },
 {
  "pkg": "ise",
  "mod": "deviceadmin/authorizationGlobalExceptionRuleUpdateRank",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/authorizationGlobalExceptionRuleUpdateRank:AuthorizationGlobalExceptionRuleUpdateRank": "AuthorizationGlobalExceptionRuleUpdateRank"
  }
 },
 {
  "pkg": "ise",
  "mod": "deviceadmin/authorizationRule",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/authorizationRule:AuthorizationRule": "AuthorizationRule"
  }
 },
 {
  "pkg": "ise",
  "mod": "deviceadmin/authorizationRuleUpdateRank",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/authorizationRuleUpdateRank:AuthorizationRuleUpdateRank": "AuthorizationRuleUpdateRank"
  }
 },
 {
  "pkg": "ise",
  "mod": "deviceadmin/condition",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/condition:Condition": "Condition"
  }
 },
 {
  "pkg": "ise",
  "mod": "deviceadmin/policySet",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/policySet:PolicySet": "PolicySet"
  }
 },
 {
  "pkg": "ise",
  "mod": "deviceadmin/policySetUpdateRank",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/policySetUpdateRank:PolicySetUpdateRank": "PolicySetUpdateRank"
  }
 },
 {
  "pkg": "ise",
  "mod": "deviceadmin/tacacsCommandSet",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/tacacsCommandSet:TacacsCommandSet": "TacacsCommandSet"
  }
 },
 {
  "pkg": "ise",
  "mod": "deviceadmin/tacacsProfile",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/tacacsProfile:TacacsProfile": "TacacsProfile"
  }
 },
 {
  "pkg": "ise",
  "mod": "deviceadmin/timeAndDateCondition",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/timeAndDateCondition:TimeAndDateCondition": "TimeAndDateCondition"
  }
 },
 {
  "pkg": "ise",
  "mod": "identitymanagement/activeDirectoryAddGroups",
  "fqn": "pulumi_ise.identitymanagement",
  "classes": {
   "ise:identitymanagement/activeDirectoryAddGroups:ActiveDirectoryAddGroups": "ActiveDirectoryAddGroups"
  }
 },
 {
  "pkg": "ise",
  "mod": "identitymanagement/activeDirectoryJoinDomainWithAllNodes",
  "fqn": "pulumi_ise.identitymanagement",
  "classes": {
   "ise:identitymanagement/activeDirectoryJoinDomainWithAllNodes:ActiveDirectoryJoinDomainWithAllNodes": "ActiveDirectoryJoinDomainWithAllNodes"
  }
 },
 {
  "pkg": "ise",
  "mod": "identitymanagement/activeDirectoryJoinPoint",
  "fqn": "pulumi_ise.identitymanagement",
  "classes": {
   "ise:identitymanagement/activeDirectoryJoinPoint:ActiveDirectoryJoinPoint": "ActiveDirectoryJoinPoint"
  }
 },
 {
  "pkg": "ise",
  "mod": "identitymanagement/certificateAuthenticationProfile",
  "fqn": "pulumi_ise.identitymanagement",
  "classes": {
   "ise:identitymanagement/certificateAuthenticationProfile:CertificateAuthenticationProfile": "CertificateAuthenticationProfile"
  }
 },
 {
  "pkg": "ise",
  "mod": "identitymanagement/endpoint",
  "fqn": "pulumi_ise.identitymanagement",
  "classes": {
   "ise:identitymanagement/endpoint:Endpoint": "Endpoint"
  }
 },
 {
  "pkg": "ise",
  "mod": "identitymanagement/endpointIdentityGroup",
  "fqn": "pulumi_ise.identitymanagement",
  "classes": {
   "ise:identitymanagement/endpointIdentityGroup:EndpointIdentityGroup": "EndpointIdentityGroup"
  }
 },
 {
  "pkg": "ise",
  "mod": "identitymanagement/identitySourceSequence",
  "fqn": "pulumi_ise.identitymanagement",
  "classes": {
   "ise:identitymanagement/identitySourceSequence:IdentitySourceSequence": "IdentitySourceSequence"
  }
 },
 {
  "pkg": "ise",
  "mod": "identitymanagement/internalUser",
  "fqn": "pulumi_ise.identitymanagement",
  "classes": {
   "ise:identitymanagement/internalUser:InternalUser": "InternalUser"
  }
 },
 {
  "pkg": "ise",
  "mod": "identitymanagement/userIdentityGroup",
  "fqn": "pulumi_ise.identitymanagement",
  "classes": {
   "ise:identitymanagement/userIdentityGroup:UserIdentityGroup": "UserIdentityGroup"
  }
 },
 {
  "pkg": "ise",
  "mod": "network/device",
  "fqn": "pulumi_ise.network",
  "classes": {
   "ise:network/device:Device": "Device"
  }
 },
 {
  "pkg": "ise",
  "mod": "network/deviceGroup",
  "fqn": "pulumi_ise.network",
  "classes": {
   "ise:network/deviceGroup:DeviceGroup": "DeviceGroup"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/allowedProtocols",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/allowedProtocols:AllowedProtocols": "AllowedProtocols"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/authenticationRule",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/authenticationRule:AuthenticationRule": "AuthenticationRule"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/authenticationRuleUpdateRank",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/authenticationRuleUpdateRank:AuthenticationRuleUpdateRank": "AuthenticationRuleUpdateRank"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/authorizationExceptionRule",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/authorizationExceptionRule:AuthorizationExceptionRule": "AuthorizationExceptionRule"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/authorizationExceptionRuleUpdateRank",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/authorizationExceptionRuleUpdateRank:AuthorizationExceptionRuleUpdateRank": "AuthorizationExceptionRuleUpdateRank"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/authorizationGlobalExceptionRule",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/authorizationGlobalExceptionRule:AuthorizationGlobalExceptionRule": "AuthorizationGlobalExceptionRule"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/authorizationGlobalExceptionRuleUpdateRank",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/authorizationGlobalExceptionRuleUpdateRank:AuthorizationGlobalExceptionRuleUpdateRank": "AuthorizationGlobalExceptionRuleUpdateRank"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/authorizationProfile",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/authorizationProfile:AuthorizationProfile": "AuthorizationProfile"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/authorizationRule",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/authorizationRule:AuthorizationRule": "AuthorizationRule"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/authorizationRuleUpdateRank",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/authorizationRuleUpdateRank:AuthorizationRuleUpdateRank": "AuthorizationRuleUpdateRank"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/condition",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/condition:Condition": "Condition"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/dictionary",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/dictionary:Dictionary": "Dictionary"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/downloadableAcl",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/downloadableAcl:DownloadableAcl": "DownloadableAcl"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/policySet",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/policySet:PolicySet": "PolicySet"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/policySetUpdateRank",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/policySetUpdateRank:PolicySetUpdateRank": "PolicySetUpdateRank"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/timeAndDateCondition",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/timeAndDateCondition:TimeAndDateCondition": "TimeAndDateCondition"
  }
 },
 {
  "pkg": "ise",
  "mod": "system/licenseTierState",
  "fqn": "pulumi_ise.system",
  "classes": {
   "ise:system/licenseTierState:LicenseTierState": "LicenseTierState"
  }
 },
 {
  "pkg": "ise",
  "mod": "system/repository",
  "fqn": "pulumi_ise.system",
  "classes": {
   "ise:system/repository:Repository": "Repository"
  }
 },
 {
  "pkg": "ise",
  "mod": "trustsec/egressMatrixCell",
  "fqn": "pulumi_ise.trustsec",
  "classes": {
   "ise:trustsec/egressMatrixCell:EgressMatrixCell": "EgressMatrixCell"
  }
 },
 {
  "pkg": "ise",
  "mod": "trustsec/egressMatrixCellDefault",
  "fqn": "pulumi_ise.trustsec",
  "classes": {
   "ise:trustsec/egressMatrixCellDefault:EgressMatrixCellDefault": "EgressMatrixCellDefault"
  }
 },
 {
  "pkg": "ise",
  "mod": "trustsec/ipToSgtMapping",
  "fqn": "pulumi_ise.trustsec",
  "classes": {
   "ise:trustsec/ipToSgtMapping:IpToSgtMapping": "IpToSgtMapping"
  }
 },
 {
  "pkg": "ise",
  "mod": "trustsec/ipToSgtMappingGroup",
  "fqn": "pulumi_ise.trustsec",
  "classes": {
   "ise:trustsec/ipToSgtMappingGroup:IpToSgtMappingGroup": "IpToSgtMappingGroup"
  }
 },
 {
  "pkg": "ise",
  "mod": "trustsec/securityGroup",
  "fqn": "pulumi_ise.trustsec",
  "classes": {
   "ise:trustsec/securityGroup:SecurityGroup": "SecurityGroup"
  }
 },
 {
  "pkg": "ise",
  "mod": "trustsec/securityGroupAcl",
  "fqn": "pulumi_ise.trustsec",
  "classes": {
   "ise:trustsec/securityGroupAcl:SecurityGroupAcl": "SecurityGroupAcl"
  }
 },
 {
  "pkg": "ise",
  "mod": "trustsec/sxpDomainFilter",
  "fqn": "pulumi_ise.trustsec",
  "classes": {
   "ise:trustsec/sxpDomainFilter:SxpDomainFilter": "SxpDomainFilter"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "ise",
  "token": "pulumi:providers:ise",
  "fqn": "pulumi_ise",
  "class": "Provider"
 }
]
"""
)
